@@ -1,6 +1,6 @@
 package Plack::Handler::Stomp;
 {
-  $Plack::Handler::Stomp::VERSION = '0.1_01';
+  $Plack::Handler::Stomp::VERSION = '0.1_02';
 }
 {
   $Plack::Handler::Stomp::DIST = 'Plack-Handler-Stomp';
@@ -326,6 +326,7 @@ sub build_psgi_env {
 
 __PACKAGE__->meta->make_immutable;
 
+
 1;
 
 __END__
@@ -339,7 +340,7 @@ Plack::Handler::Stomp - adapt STOMP to (almost) HTTP, via Plack
 
 =head1 VERSION
 
-version 0.1_01
+version 0.1_02
 
 =head1 SYNOPSIS
 
@@ -425,8 +426,8 @@ consume STOMP frames in an inner loop (see L</frame_loop>)
 =back
 
 If the application throws an exception, the loop exits re-throwing the
-exception. If the STOMP connection has problems, the outer loop is
-repeated with a different server (see
+exception. If the STOMP connection has problems, the loop is repeated
+with a different server (see
 L<next_server|Net::Stomp::MooseHelpers::CanConnect/next_server> in
 L<Net::Stomp::MooseHelpers::CanConnect>).
 
@@ -446,7 +447,10 @@ exactly 1 frame.
 Delegates the handling to L</handle_stomp_message>,
 L</handle_stomp_error>, L</handle_stomp_receipt>, or throws
 L<Plack::Handler::Stomp::Exceptions::UnknownFrame> if the frame is of
-some other kind.
+some other kind. If you want to handle different kind of frames (maybe
+because you have some non-standard STOMP server), you can just
+subclass and add methods; for example, to handle C<STRANGE> frames,
+add a C<handle_stomp_strange> method.
 
 =head2 C<handle_stomp_error>
 
@@ -511,7 +515,7 @@ Builds a PSGI environment from the message, like:
 
   # client
   REQUEST_METHOD => 'POST',
-  REQUEST_URI => "stomp://localhost$path_info",
+  REQUEST_URI => $path_info,
   SCRIPT_NAME => '',
   PATH_INFO => $path_info,
   QUERY_STRING => '',
@@ -521,6 +525,8 @@ Builds a PSGI environment from the message, like:
 
   # http
   HTTP_USER_AGENT => 'Net::Stomp',
+  HTTP_CONTENT_LENGTH => length($body),
+  HTTP_CONTENT_TYPE => $content-type,
 
   # psgi
   'psgi.version' => [1,0],
@@ -543,6 +549,11 @@ The C<$path_info> is obtained from the L</destination_path_map>
 (i.e. from the C<path_info> subscription options) passed through
 L<munge_path_info|Plack::Handler::Stomp::PathInfoMunger/munge_path_info>.
 
+=head1 EXAMPLES
+
+You can find examples of use in the tests, or at
+https://github.com/dakkar/CatalystX-StompSampleApps
+
 =head1 AUTHOR
 
 Gianni Ceccarelli <gianni.ceccarelli@net-a-porter.com>
